@@ -156,8 +156,10 @@ test_that("intercepts are handled correctly", {
 
 test_that("random effects are handled correctly", {
   expect_error(
-    obs_all_alpha <- obs(y2 ~ -1 + x2 + varying(~1) + random(~1), family = "gaussian") +
-      obs(y3 ~ -1 + x3 + varying(~x1) + trials(trials) + random(~1), family = "binomial") +
+    obs_all_alpha <- obs(y2 ~ -1 + x2 + varying(~1) + random(~1),
+                         family = "gaussian") +
+      obs(y3 ~ -1 + x3 + varying(~x1) + trials(trials) + random(~1),
+          family = "binomial") +
       obs(y4 ~ x1 + varying(~ -1 + x2), family = "bernoulli") +
       splines(df = 5) + random_spec(correlated = TRUE, noncentered = TRUE),
     NA
@@ -168,30 +170,39 @@ test_that("random effects are handled correctly", {
   )
 
   expect_error(
-    obs_all_alpha <- obs(y2 ~ -1 + x2 + varying(~1) + random(~1), family = "gaussian") +
-      obs(y3 ~ -1 + x3 + varying(~x1) + trials(trials) + random(~x1), family = "binomial") +
-      obs(y4 ~ x1 + varying(~ -1 + x2) + random(~ x1 + x2), family = "bernoulli") +
+    obs_all_alpha <- obs(y2 ~ -1 + x2 + varying(~1) + random(~1),
+                         family = "gaussian") +
+      obs(y3 ~ -1 + x3 + varying(~x1) + trials(trials) + random(~x1),
+          family = "binomial") +
+      obs(y4 ~ x1 + varying(~ -1 + x2) + random(~ x1 + x2),
+          family = "bernoulli") +
       splines(df = 5) + random_spec(correlated = FALSE),
     NA
   )
   expect_error(
-    obs_all_alpha <- obs(y2 ~ -1 + x2 + varying(~1) + random(~x2), family = "gaussian") +
-      obs(y3 ~ -1 + x3 + varying(~x1) + trials(trials) + random(~1), family = "binomial") +
+    obs_all_alpha <- obs(y2 ~ -1 + x2 + varying(~1) + random(~x2),
+                         family = "gaussian") +
+      obs(y3 ~ -1 + x3 + varying(~x1) + trials(trials) + random(~1),
+          family = "binomial") +
       obs(y4 ~ x1 + varying(~ -1 + x2), family = "bernoulli") +
       splines(df = 5) + random_spec(correlated = FALSE, noncentered = FALSE),
     NA
   )
   expect_error(
     obs_all_alpha <- obs(y2 ~ -1 + x2 + varying(~1), family = "gaussian") +
-      obs(y3 ~ -1 + x3 + varying(~x1) + trials(trials) + random(~1), family = "binomial") +
-      obs(y4 ~ x1 + varying(~ -1 + x2) + random(~ -1 + x1), family = "bernoulli") +
+      obs(y3 ~ -1 + x3 + varying(~x1) + trials(trials) + random(~1),
+          family = "binomial") +
+      obs(y4 ~ x1 + varying(~ -1 + x2) + random(~ -1 + x1),
+          family = "bernoulli") +
       splines(df = 5) + random_spec(correlated = TRUE, noncentered = FALSE),
     NA
   )
   expect_error(
     obs_all_alpha <- obs(y2 ~ -1 + x2 + varying(~1), family = "gaussian") +
-      obs(y3 ~ -1 + x3 + varying(~x1) + trials(trials) + random(~1), family = "binomial") +
-      obs(y4 ~ x1 + varying(~ -1 + x2) + random(~ -1 + x1), family = "bernoulli") +
+      obs(y3 ~ -1 + x3 + varying(~x1) + trials(trials) + random(~1),
+          family = "binomial") +
+      obs(y4 ~ x1 + varying(~ -1 + x2) + random(~ -1 + x1),
+          family = "bernoulli") +
       splines(df = 5),
     NA
   )
@@ -345,7 +356,8 @@ test_that("lags are parsed", {
     NA
   )
   expect_error(
-    obs_b <- obs(y1 ~ -1 + x1 + varying(~ lag(y2, 1)),
+    obs_b <- obs(
+      y1 ~ -1 + x1 + varying(~ lag(y2, 1)),
       family = "categorical"
     ) +
       obs(y2 ~ -1 + x2 + varying(~ lag(y1, 1)), family = "gaussian") +
@@ -406,9 +418,9 @@ test_that("higher order lags() and lag() give equal results", {
     obs(y2 ~ x2, family = "gaussian") +
     lags(k = 1:2, type = "fixed")
   f2 <- obs(y1 ~ x1 + lag(y1, 1) + lag(y2, 1) +
-    lag(y1, 2) + lag(y2, 2), family = "categorical") +
+              lag(y1, 2) + lag(y2, 2), family = "categorical") +
     obs(y2 ~ x2 + lag(y1, 1) + lag(y2, 1) +
-      lag(y1, 2) + lag(y2, 2), family = "gaussian")
+          lag(y1, 2) + lag(y2, 2), family = "gaussian")
   expect_identical(
     get_priors(f1, test_data, "time", "group"),
     get_priors(f2, test_data, "time", "group")
@@ -534,7 +546,8 @@ test_that("no groups group variable name generation works", {
 
 test_that("deterministic channels are parsed", {
   expect_error(
-    obs_det <- obs(y5 ~ x1 + lag(d, 1) + lag(y5, 1) + lag(x1, 1),
+    obs_det <- obs(
+      y5 ~ x1 + lag(d, 1) + lag(y5, 1) + lag(x1, 1),
       family = "negbin"
     ) +
       aux(numeric(d) ~ lag(d, 1) + lag(f, 2) + x2 | init(0)) +
